
## quicksong

This is a very basic program for detecting birdsong in long recordings that may be contaminated with cage noise. It uses the same general principle employed widely in the birdsong community, but instead of having to manually tweak thresholds, a support vector machine classifier is trained using manually labeled data.

